@@ -18,6 +18,8 @@
 # \arguments{
 #  \item{lx}{A @numeric @vector.
 #    Typically \code{lx} are \eqn{log(x)} values.}
+#  \item{idxs}{A @vector indicating subset of elements
+#    to operate over. If @NULL, no subsetting is done.}
 #  \item{na.rm}{If @TRUE, any missing values are ignored, otherwise not.}
 #  \item{...}{Not used.}
 # }
@@ -69,22 +71,24 @@
 #     \emph{Hyper-Textbook: Optimization Models and Applications},
 #     University of California at Berkeley, August 2012.
 #     (Chapter 'Log-Sum-Exp (LSE) Function and Properties',
-#     \url{https://inst.eecs.berkeley.edu/~ee127a/book/login/def_lse_fcn.html})
+#     \url{http://inst.eecs.berkeley.edu/~ee127a/book/login/def_lse_fcn.html})
 #     \cr
 # [3] R-help thread \emph{logsumexp function in R}, 2011-02-17.
 #     \url{https://stat.ethz.ch/pipermail/r-help/2011-February/269205.html}\cr
 # }
 #
 #*/###########################################################################
-logSumExp <- function(lx, na.rm=FALSE, ...) {
+logSumExp <- function(lx, idxs=NULL, na.rm=FALSE, ...) {
   hasNA <- TRUE;
-  .Call("logSumExp", as.numeric(lx), as.logical(na.rm), as.logical(hasNA),
+  .Call("logSumExp", as.numeric(lx), idxs, as.logical(na.rm), as.logical(hasNA),
                                                      PACKAGE="matrixStats");
 } # logSumExp()
 
 
 ##############################################################################
 # HISTORY:
+# 2015-05-28 [DJ]
+# o Supported subsetted computation.
 # 2013-04-30 [HB]
 # o Added native implementation.
 # o Renamed to logSumExp(), because that seems to be the naming convention
