@@ -1,8 +1,6 @@
 ###########################################################################/**
 # @RdocFunction rowCollapse
-# @alias rowCollapse.matrix
 # @alias colCollapse
-# @alias colCollapse.matrix
 #
 # @title "Extracts one cell per row (column) from a matrix"
 #
@@ -12,15 +10,17 @@
 # }
 #
 # \usage{
-#   @usage rowCollapse,matrix
-#   @usage colCollapse,matrix
+#   @usage rowCollapse
+#   @usage colCollapse
 # }
 #
 # \arguments{
 #   \item{x}{An NxK @matrix.}
 #   \item{idxs}{An index @vector of (maximum) length N (K) specifying the
 #    columns (rows) to be extracted.}
-#  \item{dim.}{An @integer @vector of length two specifying the
+#   \item{rows, cols}{A @vector indicating subset of rows (and/or columns)
+#    to operate over. If @NULL, no subsetting is done.}
+#   \item{dim.}{An @integer @vector of length two specifying the
 #              dimension of \code{x}, also when not a @matrix.}
 #   \item{...}{Not used.}
 # }
@@ -40,7 +40,15 @@
 #
 # @keyword utilities
 #*/###########################################################################
-setMethodS3("rowCollapse", "matrix", function(x, idxs, dim.=dim(x), ...) {
+rowCollapse <- function(x, idxs, rows=NULL, dim.=dim(x), ...) {
+  # Apply subset
+  if (is.vector(x)) dim(x) <- dim.
+  if (!is.null(rows)) {
+    x <- x[rows,,drop=FALSE]
+    idxs <- idxs[rows]
+  }
+  dim. <- dim(x)
+
   # Argument 'idxs':
   idxs <- rep(idxs, length.out=dim.[1L])
 
@@ -53,9 +61,17 @@ setMethodS3("rowCollapse", "matrix", function(x, idxs, dim.=dim(x), ...) {
   cols <- NULL # Not needed anymore
 
   x[idxs]
-})
+}
+
+colCollapse <- function(x, idxs, cols=NULL, dim.=dim(x), ...) {
+  # Apply subset
+  if (is.vector(x)) dim(x) <- dim.
+  if (!is.null(cols)) {
+    x <- x[,cols,drop=FALSE]
+    idxs <- idxs[cols]
+  }
+  dim. <- dim(x)
 
-setMethodS3("colCollapse", "matrix", function(x, idxs, dim.=dim(x), ...) {
   # Argument 'idxs':
   idxs <- rep(idxs, length.out=dim.[2L])
 
@@ -68,11 +84,15 @@ setMethodS3("colCollapse", "matrix", function(x, idxs, dim.=dim(x), ...) {
   rows <- NULL # Not needed anymore
 
   x[idxs]
-})
+}
 
 
 ############################################################################
 # HISTORY:
+# 2015-05-29 [DJ]
+# o Supported subsetted computation.
+# 2014-12-19 [HB]
+# o CLEANUP: Made col- and rowCollapse() plain R functions.
 # 2014-11-15
 # o SPEEDUP: Made calculation of colOffsets faster.
 # o SPEEDUP: Now colCollapse(x) no longer utilizes rowCollapse(t(x)).
