@@ -21,12 +21,16 @@
 #   @usage colCounts
 #   @usage rowAlls
 #   @usage colAlls
+#   @usage allValue
 #   @usage rowAnys
 #   @usage colAnys
+#   @usage anyValue
 # }
 #
 # \arguments{
 #  \item{x}{An NxK @matrix or an N*K @vector.}
+#  \item{idxs, rows, cols}{A @vector indicating subset of elements (or rows and/or columns)
+#     to operate over. If @NULL, no subsetting is done.}
 #  \item{value}{A value to search for.}
 #  \item{na.rm}{If @TRUE, @NAs are excluded first, otherwise not.}
 #  \item{dim.}{An @integer @vector of length two specifying the
@@ -53,7 +57,7 @@
 # @keyword iteration
 # @keyword univar
 #*/###########################################################################
-rowCounts <- function(x, value=TRUE, na.rm=FALSE, dim.=dim(x), ...) {
+rowCounts <- function(x, rows=NULL, cols=NULL, value=TRUE, na.rm=FALSE, dim.=dim(x), ...) {
   # Argument 'x':
   if (is.matrix(x)) {
   } else if (is.vector(x)) {
@@ -78,9 +82,16 @@ rowCounts <- function(x, value=TRUE, na.rm=FALSE, dim.=dim(x), ...) {
   if (is.numeric(x) || is.logical(x)) {
     na.rm <- as.logical(na.rm)
     hasNAs <- TRUE
-    counts <- .Call("rowCounts", x, dim., value, 2L, na.rm, hasNAs, PACKAGE="matrixStats")
+    counts <- .Call("rowCounts", x, dim., rows, cols, value, 2L, na.rm, hasNAs, PACKAGE="matrixStats")
   } else {
     if (is.vector(x)) dim(x) <- dim.
+
+    # Apply subset
+    if (!is.null(rows) && !is.null(cols)) x <- x[rows,cols,drop=FALSE]
+    else if (!is.null(rows)) x <- x[rows,,drop=FALSE]
+    else if (!is.null(cols)) x <- x[,cols,drop=FALSE]
+    dim. <- dim(x)
+
     if (is.na(value)) {
       counts <- apply(x, MARGIN=1L, FUN=function(x) sum(is.na(x)))
     } else {
@@ -92,7 +103,7 @@ rowCounts <- function(x, value=TRUE, na.rm=FALSE, dim.=dim(x), ...) {
 } # rowCounts()
 
 
-colCounts <- function(x, value=TRUE, na.rm=FALSE, dim.=dim(x), ...) {
+colCounts <- function(x, rows=NULL, cols=NULL, value=TRUE, na.rm=FALSE, dim.=dim(x), ...) {
   # Argument 'x':
   if (is.matrix(x)) {
   } else if (is.vector(x)) {
@@ -111,16 +122,22 @@ colCounts <- function(x, value=TRUE, na.rm=FALSE, dim.=dim(x), ...) {
   # Coerce 'value' to matrix
   storage.mode(value) <- storage.mode(x)
 
-
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Count
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   if (is.numeric(x) || is.logical(x)) {
     na.rm <- as.logical(na.rm)
     hasNAs <- TRUE
-    counts <- .Call("colCounts", x, dim., value, 2L, na.rm, hasNAs, PACKAGE="matrixStats")
+    counts <- .Call("colCounts", x, dim., rows, cols, value, 2L, na.rm, hasNAs, PACKAGE="matrixStats")
   } else {
     if (is.vector(x)) dim(x) <- dim.
+
+    # Apply subset
+    if (!is.null(rows) && !is.null(cols)) x <- x[rows,cols,drop=FALSE]
+    else if (!is.null(rows)) x <- x[rows,,drop=FALSE]
+    else if (!is.null(cols)) x <- x[,cols,drop=FALSE]
+    dim. <- dim(x)
+
     if (is.na(value)) {
       counts <- apply(x, MARGIN=2L, FUN=function(x) sum(is.na(x)))
     } else {
@@ -133,7 +150,7 @@ colCounts <- function(x, value=TRUE, na.rm=FALSE, dim.=dim(x), ...) {
 
 
 
-count <- function(x, value=TRUE, na.rm=FALSE, ...) {
+count <- function(x, idxs=NULL, value=TRUE, na.rm=FALSE, ...) {
   # Argument 'x':
   if (!is.vector(x)) {
     stop("Argument 'x' must be a vector: ", mode(x)[1L])
@@ -147,15 +164,17 @@ count <- function(x, value=TRUE, na.rm=FALSE, ...) {
   # Coerce 'value' to matrix
   storage.mode(value) <- storage.mode(x)
 
-
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Count
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   if (is.numeric(x) || is.logical(x)) {
     na.rm <- as.logical(na.rm)
     hasNAs <- TRUE
-    counts <- .Call("count", x, value, 2L, na.rm, hasNAs, PACKAGE="matrixStats")
+    counts <- .Call("count", x, idxs, value, 2L, na.rm, hasNAs, PACKAGE="matrixStats")
   } else {
+    # Apply subset
+    if (!is.null(idxs)) x <- x[idxs]
+
     if (is.na(value)) {
       counts <- sum(is.na(x))
     } else {
@@ -168,13 +187,21 @@ count <- function(x, value=TRUE, na.rm=FALSE, ...) {
 
 
 
-rowAlls <- function(x, value=TRUE, na.rm=FALSE, dim.=dim(x), ...) {
+rowAlls <- function(x, rows=NULL, cols=NULL, value=TRUE, na.rm=FALSE, dim.=dim(x), ...) {
   if (is.numeric(x) || is.logical(x)) {
     na.rm <- as.logical(na.rm)
     hasNAs <- TRUE
-    counts <- .Call("rowCounts", x, dim., value, 0L, na.rm, hasNAs, PACKAGE="matrixStats")
+    counts <- .Call("rowCounts", x, dim., rows, cols, value, 0L, na.rm, hasNAs, PACKAGE="matrixStats")
     as.logical(counts)
   } else {
+    if (is.vector(x)) dim(x) <- dim.
+
+    # Apply subset
+    if (!is.null(rows) && !is.null(cols)) x <- x[rows,cols,drop=FALSE]
+    else if (!is.null(rows)) x <- x[rows,,drop=FALSE]
+    else if (!is.null(cols)) x <- x[,cols,drop=FALSE]
+    dim. <- dim(x)
+
     if (is.na(value)) {
       rowAlls(is.na(x), na.rm=na.rm, dim.=dim., ...)
     } else {
@@ -183,13 +210,21 @@ rowAlls <- function(x, value=TRUE, na.rm=FALSE, dim.=dim(x), ...) {
   }
 }
 
-colAlls <- function(x, value=TRUE, na.rm=FALSE, dim.=dim(x), ...) {
+colAlls <- function(x, rows=NULL, cols=NULL, value=TRUE, na.rm=FALSE, dim.=dim(x), ...) {
   if (is.numeric(x) || is.logical(x)) {
     na.rm <- as.logical(na.rm)
     hasNAs <- TRUE
-    counts <- .Call("colCounts", x, dim., value, 0L, na.rm, hasNAs, PACKAGE="matrixStats")
+    counts <- .Call("colCounts", x, dim., rows, cols, value, 0L, na.rm, hasNAs, PACKAGE="matrixStats")
     as.logical(counts)
   } else {
+    if (is.vector(x)) dim(x) <- dim.
+
+    # Apply subset
+    if (!is.null(rows) && !is.null(cols)) x <- x[rows,cols,drop=FALSE]
+    else if (!is.null(rows)) x <- x[rows,,drop=FALSE]
+    else if (!is.null(cols)) x <- x[,cols,drop=FALSE]
+    dim. <- dim(x)
+
     if (is.na(value)) {
       colAlls(is.na(x), na.rm=na.rm, dim.=dim., ...)
     } else {
@@ -199,13 +234,16 @@ colAlls <- function(x, value=TRUE, na.rm=FALSE, dim.=dim(x), ...) {
 }
 
 
-allValue <- function(x, value=TRUE, na.rm=FALSE, ...) {
+allValue <- function(x, idxs=NULL, value=TRUE, na.rm=FALSE, ...) {
   if (is.numeric(x) || is.logical(x)) {
     na.rm <- as.logical(na.rm)
     hasNAs <- TRUE
-    counts <- .Call("count", x, value, 0L, na.rm, hasNAs, PACKAGE="matrixStats")
+    counts <- .Call("count", x, idxs, value, 0L, na.rm, hasNAs, PACKAGE="matrixStats")
     as.logical(counts)
   } else {
+    # Apply subset
+    if (!is.null(idxs)) x <- x[idxs]
+
     if (is.na(value)) {
       allValue(is.na(x), na.rm=na.rm, ...)
     } else {
@@ -216,13 +254,21 @@ allValue <- function(x, value=TRUE, na.rm=FALSE, ...) {
 
 
 
-rowAnys <- function(x, value=TRUE, na.rm=FALSE, dim.=dim(x), ...) {
+rowAnys <- function(x, rows=NULL, cols=NULL, value=TRUE, na.rm=FALSE, dim.=dim(x), ...) {
   if (is.numeric(x) || is.logical(x)) {
     na.rm <- as.logical(na.rm)
     hasNAs <- TRUE
-    counts <- .Call("rowCounts", x, dim., value, 1L, na.rm, hasNAs, PACKAGE="matrixStats")
+    counts <- .Call("rowCounts", x, dim., rows, cols, value, 1L, na.rm, hasNAs, PACKAGE="matrixStats")
     as.logical(counts)
   } else {
+    if (is.vector(x)) dim(x) <- dim.
+
+    # Apply subset
+    if (!is.null(rows) && !is.null(cols)) x <- x[rows,cols,drop=FALSE]
+    else if (!is.null(rows)) x <- x[rows,,drop=FALSE]
+    else if (!is.null(cols)) x <- x[,cols,drop=FALSE]
+    dim. <- dim(x)
+
     if (is.na(value)) {
       rowAnys(is.na(x), na.rm=na.rm, dim.=dim., ...)
     } else {
@@ -231,13 +277,21 @@ rowAnys <- function(x, value=TRUE, na.rm=FALSE, dim.=dim(x), ...) {
   }
 }
 
-colAnys <- function(x, value=TRUE, na.rm=FALSE, dim.=dim(x), ...) {
+colAnys <- function(x, rows=NULL, cols=NULL, value=TRUE, na.rm=FALSE, dim.=dim(x), ...) {
   if (is.numeric(x) || is.logical(x)) {
     na.rm <- as.logical(na.rm)
     hasNAs <- TRUE
-    counts <- .Call("colCounts", x, dim., value, 1L, na.rm, hasNAs, PACKAGE="matrixStats")
+    counts <- .Call("colCounts", x, dim., rows, cols, value, 1L, na.rm, hasNAs, PACKAGE="matrixStats")
     as.logical(counts)
   } else {
+    if (is.vector(x)) dim(x) <- dim.
+
+    # Apply subset
+    if (!is.null(rows) && !is.null(cols)) x <- x[rows,cols,drop=FALSE]
+    else if (!is.null(rows)) x <- x[rows,,drop=FALSE]
+    else if (!is.null(cols)) x <- x[,cols,drop=FALSE]
+    dim. <- dim(x)
+
     if (is.na(value)) {
       colAnys(is.na(x), na.rm=na.rm, dim.=dim., ...)
     } else {
@@ -247,13 +301,16 @@ colAnys <- function(x, value=TRUE, na.rm=FALSE, dim.=dim(x), ...) {
 }
 
 
-anyValue <- function(x, value=TRUE, na.rm=FALSE, ...) {
+anyValue <- function(x, idxs=NULL, value=TRUE, na.rm=FALSE, ...) {
   if (is.numeric(x) || is.logical(x)) {
     na.rm <- as.logical(na.rm)
     hasNAs <- TRUE
-    counts <- .Call("count", x, value, 1L, na.rm, hasNAs, PACKAGE="matrixStats")
+    counts <- .Call("count", x, idxs, value, 1L, na.rm, hasNAs, PACKAGE="matrixStats")
     as.logical(counts)
   } else {
+    # Apply subset
+    if (!is.null(idxs)) x <- x[idxs]
+
     if (is.na(value)) {
       anyValue(is.na(x), na.rm=na.rm, ...)
     } else {
@@ -266,6 +323,8 @@ anyValue <- function(x, value=TRUE, na.rm=FALSE, ...) {
 
 ############################################################################
 # HISTORY:
+# 2015-05-26 [DJ]
+# o Supported subsetted computation.
 # 2014-11-14 [HB]
 # o SPEEDUP: Now colCounts() is implemented in native code.
 # o CLEANUP: Now (col|row)Count(x) when x is logical utilizes the
