@@ -15,6 +15,10 @@
 #
 # \arguments{
 #  \item{x}{A @numeric NxK @matrix.}
+#  \item{rows, cols}{A @vector indicating subset of rows (and/or columns)
+#     to operate over. If @NULL, no subsetting is done.}
+#  \item{lag}{An @integer specifying the lag.}
+#  \item{differences}{An @integer specifying the order of difference.}
 #  \item{...}{Not used.}
 # }
 #
@@ -27,7 +31,7 @@
 # @author "HB"
 #
 # \seealso{
-#   Internally @see "base::diff" is used.
+#   See also @see "diff2".
 # }
 #
 # @keyword array
@@ -35,28 +39,19 @@
 # @keyword robust
 # @keyword univar
 #*/###########################################################################
-rowDiffs <- function(x, ...) {
-  naValue <- NA;
-  storage.mode(naValue) <- storage.mode(x);
-  d <- matrix(naValue, nrow=nrow(x), ncol=ncol(x)-1L);
-  for (rr in seq(length=nrow(x))) {
-    d[rr,] <- diff(x[rr,], ...);
-  }
-  d;
+rowDiffs <- function(x, rows=NULL, cols=NULL, lag=1L, differences=1L, ...) {
+  .Call("rowDiffs", x, dim(x), rows, cols, as.integer(lag), as.integer(differences), TRUE, PACKAGE="matrixStats")
 }
 
-colDiffs <- function(x, ...) {
-  naValue <- NA;
-  storage.mode(naValue) <- storage.mode(x);
-  d <- matrix(naValue, nrow=nrow(x)-1L, ncol=ncol(x));
-  for (cc in seq(length=ncol(x))) {
-    d[,cc] <- diff(x[,cc], ...);
-  }
-  d;
+colDiffs <- function(x, rows=NULL, cols=NULL, lag=1L, differences=1L, ...) {
+  .Call("rowDiffs", x, dim(x), rows, cols, as.integer(lag), as.integer(differences), FALSE, PACKAGE="matrixStats")
 }
 
+
 ############################################################################
 # HISTORY:
+# 2015-05-30 [DJ]
+# o Supported subsetted computation.
 # 2014-11-15 [HB]
 # o SPEEDUP: Now colDiffs(x) no longer uses rowDiffs(t(x)).
 # 2008-03-26 [HB]
