@@ -18,6 +18,8 @@
 #
 # \arguments{
 #  \item{x}{A @numeric NxK @matrix.}
+#  \item{rows, cols}{A @vector indicating subset of rows (and/or columns)
+#     to operate over. If @NULL, no subsetting is done.}
 #  \item{center}{(optional) The center, defaults to the row means.}
 #  \item{na.rm}{If @TRUE, @NAs are excluded first, otherwise not.}
 #  \item{dim.}{An @integer @vector of length two specifying the
@@ -43,15 +45,26 @@
 # @keyword robust
 # @keyword univar
 #*/###########################################################################
-rowVars <- function(x, na.rm=FALSE, center=NULL, dim.=dim(x), ...) {
+rowVars <- function(x, rows=NULL, cols=NULL, na.rm=FALSE, center=NULL, dim.=dim(x), ...) {
+  dim. <- as.integer(dim.)
+
   if (is.null(center)) {
-    dim. <- as.integer(dim.)
     na.rm <- as.logical(na.rm)
     hasNAs <- TRUE
-    sigma2 <- .Call("rowVars", x, dim., na.rm, hasNAs, TRUE, PACKAGE="matrixStats");
+    sigma2 <- .Call("rowVars", x, dim., rows, cols, na.rm, hasNAs, TRUE, PACKAGE="matrixStats");
     return(sigma2)
   }
 
+  # Apply subset on 'x'
+  if (is.vector(x)) dim(x) <- dim.
+  if (!is.null(rows) && !is.null(cols)) x <- x[rows,cols,drop=FALSE]
+  else if (!is.null(rows)) x <- x[rows,,drop=FALSE]
+  else if (!is.null(cols)) x <- x[,cols,drop=FALSE]
+  dim. <- dim(x)
+
+  # Apply subset on 'center'
+  if (!is.null(rows)) center <- center[rows]
+
   ncol <- ncol(x);
 
   # Nothing to do?
@@ -90,15 +103,27 @@ rowVars <- function(x, na.rm=FALSE, center=NULL, dim.=dim(x), ...) {
 }
 
 
-colVars <- function(x, na.rm=FALSE, center=NULL, dim.=dim(x), ...) {
+colVars <- function(x, rows=NULL, cols=NULL, na.rm=FALSE, center=NULL, dim.=dim(x), ...) {
+  dim. <- as.integer(dim.)
+
   if (is.null(center)) {
     dim. <- as.integer(dim.)
     na.rm <- as.logical(na.rm)
     hasNAs <- TRUE
-    sigma2 <- .Call("rowVars", x, dim., na.rm, hasNAs, FALSE, PACKAGE="matrixStats");
+    sigma2 <- .Call("rowVars", x, dim., rows, cols, na.rm, hasNAs, FALSE, PACKAGE="matrixStats");
     return(sigma2)
   }
 
+  # Apply subset on 'x'
+  if (is.vector(x)) dim(x) <- dim.
+  if (!is.null(rows) && !is.null(cols)) x <- x[rows,cols,drop=FALSE]
+  else if (!is.null(rows)) x <- x[rows,,drop=FALSE]
+  else if (!is.null(cols)) x <- x[,cols,drop=FALSE]
+  dim. <- dim(x)
+
+  # Apply subset on 'center'
+  if (!is.null(cols)) center <- center[cols]
+
   nrow <- nrow(x);
 
   # Nothing to do?
